package com.mindfusion.barchart;

import java.util.ArrayList;

import com.mindfusion.charting.AxesChart;
import com.mindfusion.charting.AxisLabelType;
import com.mindfusion.charting.BarSeries;
import com.mindfusion.charting.BarType;

import android.os.Bundle;
import android.app.Activity;
import android.graphics.Color;
import android.graphics.DashPathEffect;
import android.view.Menu;
import android.view.View;
import android.widget.AdapterView;
import android.widget.AdapterView.OnItemSelectedListener;
import android.widget.ArrayAdapter;
import android.widget.Spinner;

public class MainActivity extends Activity implements OnItemSelectedListener {

	private AxesChart chart;
	BarSeries series1;
	BarSeries series2;
	BarSeries series3;
	
	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.activity_main);
		
		chart = (AxesChart)findViewById(R.id.chart);
		
		chart.setTitle("Sales Overview");
				
		chart.xAxisSettings.setMin(0f);
		chart.xAxisSettings.setMax(5f);
		chart.xAxisSettings.setInterval(1f);
		
		chart.yAxisSettings.setMin(0f);
		chart.yAxisSettings.setMax(500f);
		chart.yAxisSettings.setInterval(50f);
		chart.yAxisSettings.setLabelType(AxisLabelType.Scale);
		chart.yAxisSettings.setTitle("Sales");
		chart.yAxisSettings.setTitleOffset(10f);
		
		ArrayList<String> labels = new ArrayList<String>();
		labels.add("2008");
		labels.add("2009");
		labels.add("2010");
		labels.add("2011");
		labels.add("2012");
				
		chart.xAxisSettings.setLabels(labels);
		chart.xAxisSettings.setLabelType(AxisLabelType.Custom);
		chart.xAxisSettings.setTitle("Year");		
		
		ArrayList<Integer>gridStrokeColors = new ArrayList<Integer>();
		gridStrokeColors.add(Color.rgb(192, 192, 192));
		
		chart.setGridStrokeColors(gridStrokeColors);
		
		DashPathEffect effect = new DashPathEffect(new float[] {10,5}, 0);
		chart.setGridStrokeEffect(effect);
		
		ArrayList<Float> xData = new ArrayList<Float>();

		for(int i = 0; i < 5; i++)
			xData.add((float)i);

		//first series
		series1 = new BarSeries();
		series1.setXData(xData);

		ArrayList<Float> yData1 = new ArrayList<Float>();
		yData1.add(234f);
		yData1.add(315f);
		yData1.add(265f);
		yData1.add(302f);
		yData1.add(276f);
		series1.setYData(yData1);

		ArrayList<Integer> fillColors1 = new ArrayList<Integer>();
		fillColors1.add(Color.rgb(167, 210, 252));
		series1.setFillColors(fillColors1);

		ArrayList<Integer> strokeColors1 = new ArrayList<Integer>();
		strokeColors1.add(Color.rgb(94, 149, 204));
		series1.setStrokeColors(strokeColors1);

		chart.addSeries(series1);	

		//second series
		series2 = new BarSeries();
		series2.setXData(xData);

		ArrayList<Float> yData2 = new ArrayList<Float>();
		yData2.add(314f);
		yData2.add(421f);
		yData2.add(102f);
		yData2.add(89f);
		yData2.add(389f);
		series2.setYData(yData2);

		ArrayList<Integer> fillColors2 = new ArrayList<Integer>();
		fillColors2.add(Color.rgb(245, 212, 152));
		series2.setFillColors(fillColors2);

		ArrayList<Integer> strokeColors2 = new ArrayList<Integer>();
		strokeColors2.add(Color.rgb(235, 185, 94));
		series2.setStrokeColors(strokeColors2);

		chart.addSeries(series2);	
		
		//third series
		series3 = new BarSeries();
		series3.setXData(xData);

		ArrayList<Float> yData3 = new ArrayList<Float>();
		yData3.add(212f);
		yData3.add(106f);
		yData3.add(89f);
		yData3.add(143f);
		yData3.add(178f);
		series3.setYData(yData3);

		ArrayList<Integer> fillColors3 = new ArrayList<Integer>();
		fillColors3.add(Color.rgb(232, 196, 245));
		series3.setFillColors(fillColors3);

		ArrayList<Integer> strokeColors3 = new ArrayList<Integer>();
		strokeColors3.add(Color.rgb(181, 97, 212));
		series3.setStrokeColors(strokeColors3);

		chart.addSeries(series3);	
	

		Spinner spinner = (Spinner) findViewById(R.id.bartypes_spinner);
		// Create an ArrayAdapter using the string array and a default spinner layout
		ArrayAdapter<CharSequence> adapter = ArrayAdapter.createFromResource(this,
		        R.array.bartypes_array, android.R.layout.simple_spinner_item);
		// Specify the layout to use when the list of choices appears
		adapter.setDropDownViewResource(android.R.layout.simple_spinner_dropdown_item);
		// Apply the adapter to the spinner
		spinner.setAdapter(adapter);
		spinner.setOnItemSelectedListener(this);		
	}

	@Override
	public boolean onCreateOptionsMenu(Menu menu) {
		// Inflate the menu; this adds items to the action bar if it is present.
		getMenuInflater().inflate(R.menu.main, menu);
		return true;
	}

	@Override
	public void onItemSelected(AdapterView<?> parent, View view, 
            int pos, long id) {
        // An item was selected. You can retrieve the selected item using
        // parent.getItemAtPosition(pos)
		
		String selected = parent.getItemAtPosition(pos).toString();
		
		if(selected.equals("Stacked"))
		{
			series1.setBarType(BarType.VerticalStacked);
			series2.setBarType(BarType.VerticalStacked);	
			series3.setBarType(BarType.VerticalStacked);
			chart.yAxisSettings.setMax(1000);
			chart.yAxisSettings.setInterval(100);
		}
		else if(selected.equals("Overlay"))
		{
			series1.setBarType(BarType.VerticalOverlay);
			series2.setBarType(BarType.VerticalOverlay);	
			series3.setBarType(BarType.VerticalOverlay);
			chart.yAxisSettings.setMax(500);
			chart.yAxisSettings.setInterval(50);
		}
		else if(selected.equals("Vertical"))
		{
			series1.setBarType(BarType.Vertical);
			series2.setBarType(BarType.Vertical);	
			series3.setBarType(BarType.Vertical);
			chart.yAxisSettings.setMax(500);
			chart.yAxisSettings.setInterval(50);
		}
    }


	@Override
	public void onNothingSelected(AdapterView<?> arg0) {
		// TODO Auto-generated method stub
		
	}

}
